==> tellico_3.4.6.orig.tar.xz: tellico-3.4.6/src/gui/spinbox.h <==
/***************************************************************************
    Copyright (C) 2003-2009 Robby Stephenson <robby@periapsis.org>
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or         *
 *   modify it under the terms of the GNU General Public License as        *
 *   published by the Free Software Foundation; either version 2 of        *
 *   the License or (at your option) version 3 or any later version        *
 *   accepted by the membership of KDE e.V. (or its successor approved     *
 *   by the membership of KDE e.V.), which shall act as a proxy            *
 *   defined in Section 14 of version 3 of the license.                    *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>. *
 *                                                                         *
 ***************************************************************************/

#ifndef TELLICO_GUI_SPINBOX_H
#define TELLICO_GUI_SPINBOX_H

#include <QSpinBox>

namespace Tellico {
  namespace GUI {

/**
 * @author Robby Stephenson
 */
class SpinBox : public QSpinBox {
Q_OBJECT

public:
  SpinBox(int min, int max, QWidget* parent);

  virtual void stepBy(int steps) Q_DECL_OVERRIDE;

private Q_SLOTS:
  void checkValue(const QString&);

private:
  QValidator::State validate(QString& text, int& pos) const Q_DECL_OVERRIDE;
};

  } // end namespace
} // end namespace
#endif

==> tellico-4.1.3.tar.xz: tellico-4.1.3/src/gui/spinbox.h <==
/***************************************************************************
    Copyright (C) 2003-2009 Robby Stephenson <robby@periapsis.org>
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or         *
 *   modify it under the terms of the GNU General Public License as        *
 *   published by the Free Software Foundation; either version 2 of        *
 *   the License or (at your option) version 3 or any later version        *
 *   accepted by the membership of KDE e.V. (or its successor approved     *
 *   by the membership of KDE e.V.), which shall act as a proxy            *
 *   defined in Section 14 of version 3 of the license.                    *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>. *
 *                                                                         *
 ***************************************************************************/

#ifndef TELLICO_GUI_SPINBOX_H
#define TELLICO_GUI_SPINBOX_H

#include <QSpinBox>

namespace Tellico {
  namespace GUI {

/**
 * @author Robby Stephenson
 */
class SpinBox : public QSpinBox {
Q_OBJECT

public:
  SpinBox(int min, int max, QWidget* parent);

  virtual void stepBy(int steps) override;

private Q_SLOTS:
  void checkValue(const QString&);

private:
  QValidator::State validate(QString& text, int& pos) const override;
};

  } // end namespace
} // end namespace
#endif
